bayespy.inference.vmp.nodes.gaussian.WrapToGaussianGammaISO.plot
================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: WrapToGaussianGammaISO.plot